@@ -432,6 +432,14 @@ void test_ggo_7 () {
         char *iface = g_strdup (gssdp_client_get_interface (client));
         g_clear_object (&client);
 
+#ifdef G_OS_UNIX
+#if defined(__linux__)
+        g_assert_cmpstr (iface, ==, "lo");
+#else
+        g_assert_cmpstr (iface, ==, "lo0");
+#endif
+#endif
+
         g_debug("Found adapter %s for 127.0.0.1", iface);
 
         // Check that trying to get a client for a non-existing interface fails
@@ -463,44 +471,6 @@ void test_ggo_7 () {
  * ============================================================================
  */
 
-/* BEGIN Regression test
- * https://gitlab.gnome.org/GNOME/gssdp/issues/22
- * ============================================================================
- *  - Calling can_reach on a v4 link-local address causes a warning
- */
-
-void
-test_ggo_22 ()
-{
-        GError *error = NULL;
-        GInetAddress *addr = g_inet_address_new_any (G_SOCKET_FAMILY_IPV4);
-        GInetAddress *target_addr =
-                g_inet_address_new_from_string ("169.254.140.39");
-        GSocketAddress *target = g_inet_socket_address_new (target_addr, 0);
-
-        GSSDPClient *client = g_initable_new (GSSDP_TYPE_CLIENT,
-                                              NULL,
-                                              &error,
-                                              "host-ip",
-                                              "127.0.0.1",
-                                              NULL);
-
-        g_assert_nonnull (client);
-        g_assert_no_error (error);
-
-        // don't care for the result, just make sure that there is no warning
-        (void) gssdp_client_can_reach (client, G_INET_SOCKET_ADDRESS (target));
-
-        g_object_unref (client);
-        g_object_unref (target);
-        g_object_unref (target_addr);
-        g_object_unref (addr);
-}
-
-/* END Regression test
- * https://gitlab.gnome.org/GNOME/gssdp/issues/7
- * ============================================================================
- */
 
 int main (int argc, char *argv[])
 {
@@ -516,7 +486,6 @@ int main (int argc, char *argv[])
                g_test_add_func ("/bugs/ggo/1", test_ggo_1);
         }
         g_test_add_func ("/bugs/ggo/7", test_ggo_7);
-        g_test_add_func ("/bugs/ggo/22", test_ggo_22);
 
         g_test_run ();
 
